==> estateplat-common-1.2.4-20211216.073108-953-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZdxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import java.util.Date;

/**
 * 宗地信息实体类
 * Created by lst on 2015/3/12.
 */
public class DjsjZdxx {
    private String zdDjdcbIndex;
    private String tdzl;
    private Double fzmj;
    @Zd(table = "bdcsjgl.s_zd_dldm")
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    private String tdjb;
    private Double qdjg;
    private String qsxz;
    @Zd(table = "bdcsjgl.s_zd_tdsyqlx")
    private String syqlx;
    private Double jzrjl;
    private Double jzmd;
    private Double jzxg;
    private String zdsz;
    private String gysyqqh;
    private Date qsrq;
    private Date zzrq;
    private Date qsrq2;
    private Date zzrq2;
    private Date qsrq3;
    private Date zzrq3;
    private String qlrmc;
    private String qlrzjlx;
    private String qlrzjh;
    private String dwxz;
    private String frdbxm;
    private String frdbzjlx;
    private String frdbzjh;
    private String frdbdhhm;
    private String dlrxm;
    private String djh;
    private String dlrdhhm;
    private String txdz;
    private Double scmj;
    private String tdsyqr;
    private String bdcdyh;
    private String mjdw;
    private String qlsdfs;
    private String bdczt;//不动产状态
    private Double pzmj;
    private String dj;//等级
    private String pzyt;//批准用途
    private String sfgyz;//是否共有宗
    private String zdszb;
    private String zdszn;
    private String zdszd;
    private String zdszx;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 备注
     */
    private String bz;
    private Double jzdj;//基准地价
    private Double jzdj2;//基准地价2
    private Double jzdj3;//基准地价3
    private String ghytmc;
    private String ydyhfl;

    public String getSfgyz() {
        return sfgyz;
    }

    public void setSfgyz(String sfgyz) {
        this.sfgyz = sfgyz;
    }
    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getFrdbxm() {
        return frdbxm;
    }

    public void setFrdbxm(String frdbxm) {
        this.frdbxm = frdbxm;
    }

    public String getFrdbzjlx() {
        return frdbzjlx;
    }

    public void setFrdbzjlx(String frdbzjlx) {
        this.frdbzjlx = frdbzjlx;
    }

    public String getFrdbzjh() {
        return frdbzjh;
    }

    public void setFrdbzjh(String frdbzjh) {
        this.frdbzjh = frdbzjh;
    }

    public String getFrdbdhhm() {
        return frdbdhhm;
    }

    public void setFrdbdhhm(String frdbdhhm) {
        this.frdbdhhm = frdbdhhm;
    }

    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getDlrdhhm() {
        return dlrdhhm;
    }

    public void setDlrdhhm(String dlrdhhm) {
        this.dlrdhhm = dlrdhhm;
    }


    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdDjdcbIndex() {
        return zdDjdcbIndex;
    }

    public void setZdDjdcbIndex(String zdDjdcbIndex) {
        this.zdDjdcbIndex = zdDjdcbIndex;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdjb() {
        return tdjb;
    }

    public void setTdjb(String tdjb) {
        this.tdjb = tdjb;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public Double getJzrjl() {
        return jzrjl;
    }

    public void setJzrjl(Double jzrjl) {
        this.jzrjl = jzrjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getGysyqqh() {
        return gysyqqh;
    }

    public void setGysyqqh(String gysyqqh) {
        this.gysyqqh = gysyqqh;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getDwxz() {
        return dwxz;
    }

    public void setDwxz(String dwxz) {
        this.dwxz = dwxz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Date getQsrq2() {
        return qsrq2;
    }

    public void setQsrq2(Date qsrq2) {
        this.qsrq2 = qsrq2;
    }

    public Date getZzrq2() {
        return zzrq2;
    }

    public void setZzrq2(Date zzrq2) {
        this.zzrq2 = zzrq2;
    }

    public Date getQsrq3() {
        return qsrq3;
    }

    public void setQsrq3(Date qsrq3) {
        this.qsrq3 = qsrq3;
    }

    public Date getZzrq3() {
        return zzrq3;
    }

    public void setZzrq3(Date zzrq3) {
        this.zzrq3 = zzrq3;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }

    public String getTdyt3() {
        return tdyt3;
    }

    public void setTdyt3(String tdyt3) {
        this.tdyt3 = tdyt3;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public Double getPzmj() {
        return pzmj;
    }

    public void setPzmj(Double pzmj) {
        this.pzmj = pzmj;
    }

    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public Double getJzdj() {
        return jzdj;
    }

    public void setJzdj(Double jzdj) {
        this.jzdj = jzdj;
    }

    public Double getJzdj2() {
        return jzdj2;
    }

    public void setJzdj2(Double jzdj2) {
        this.jzdj2 = jzdj2;
    }

    public Double getJzdj3() {
        return jzdj3;
    }

    public void setJzdj3(Double jzdj3) {
        this.jzdj3 = jzdj3;
    }

}

==> estateplat-common-1.2.4-20241105.073505-1266-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZdxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import java.util.Date;

/**
 * 宗地信息实体类
 * Created by lst on 2015/3/12.
 */
public class DjsjZdxx {
    private String zdDjdcbIndex;
    private String tdzl;
    private Double fzmj;
    @Zd(table = "bdcsjgl.s_zd_dldm")
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    private String tdjb;
    private Double qdjg;
    private String qsxz;
    @Zd(table = "bdcsjgl.s_zd_tdsyqlx")
    private String syqlx;
    private Double jzrjl;
    private Double jzmd;
    private Double jzxg;
    private String zdsz;
    private String gysyqqh;
    private Date qsrq;
    private Date zzrq;
    private Date qsrq2;
    private Date zzrq2;
    private Date qsrq3;
    private Date zzrq3;
    private String qlrmc;
    private String qlrzjlx;
    private String qlrzjh;
    private String dwxz;
    private String frdbxm;
    private String frdbzjlx;
    private String frdbzjh;
    private String frdbdhhm;
    private String dlrxm;
    private String djh;
    private String dlrdhhm;
    private String txdz;
    private Double scmj;
    private String tdsyqr;
    private String bdcdyh;
    private String mjdw;
    private String qlsdfs;
    private String bdczt;//不动产状态
    private Double pzmj;
    private String dj;//等级
    private String pzyt;//批准用途
    private String sfgyz;//是否共有宗
    private String zdszb;
    private String zdszn;
    private String zdszd;
    private String zdszx;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 备注
     */
    private String bz;
    private Double jzdj;//基准地价
    private Double jzdj2;//基准地价2
    private Double jzdj3;//基准地价3
    private String ghytmc;
    private String ydyhfl;
    private Double zdzmj;
    private Double jzzmj;

    public String getSfgyz() {
        return sfgyz;
    }

    public void setSfgyz(String sfgyz) {
        this.sfgyz = sfgyz;
    }
    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getFrdbxm() {
        return frdbxm;
    }

    public void setFrdbxm(String frdbxm) {
        this.frdbxm = frdbxm;
    }

    public String getFrdbzjlx() {
        return frdbzjlx;
    }

    public void setFrdbzjlx(String frdbzjlx) {
        this.frdbzjlx = frdbzjlx;
    }

    public String getFrdbzjh() {
        return frdbzjh;
    }

    public void setFrdbzjh(String frdbzjh) {
        this.frdbzjh = frdbzjh;
    }

    public String getFrdbdhhm() {
        return frdbdhhm;
    }

    public void setFrdbdhhm(String frdbdhhm) {
        this.frdbdhhm = frdbdhhm;
    }

    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getDlrdhhm() {
        return dlrdhhm;
    }

    public void setDlrdhhm(String dlrdhhm) {
        this.dlrdhhm = dlrdhhm;
    }


    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdDjdcbIndex() {
        return zdDjdcbIndex;
    }

    public void setZdDjdcbIndex(String zdDjdcbIndex) {
        this.zdDjdcbIndex = zdDjdcbIndex;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdjb() {
        return tdjb;
    }

    public void setTdjb(String tdjb) {
        this.tdjb = tdjb;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public Double getJzrjl() {
        return jzrjl;
    }

    public void setJzrjl(Double jzrjl) {
        this.jzrjl = jzrjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getGysyqqh() {
        return gysyqqh;
    }

    public void setGysyqqh(String gysyqqh) {
        this.gysyqqh = gysyqqh;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getDwxz() {
        return dwxz;
    }

    public void setDwxz(String dwxz) {
        this.dwxz = dwxz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Date getQsrq2() {
        return qsrq2;
    }

    public void setQsrq2(Date qsrq2) {
        this.qsrq2 = qsrq2;
    }

    public Date getZzrq2() {
        return zzrq2;
    }

    public void setZzrq2(Date zzrq2) {
        this.zzrq2 = zzrq2;
    }

    public Date getQsrq3() {
        return qsrq3;
    }

    public void setQsrq3(Date qsrq3) {
        this.qsrq3 = qsrq3;
    }

    public Date getZzrq3() {
        return zzrq3;
    }

    public void setZzrq3(Date zzrq3) {
        this.zzrq3 = zzrq3;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }

    public String getTdyt3() {
        return tdyt3;
    }

    public void setTdyt3(String tdyt3) {
        this.tdyt3 = tdyt3;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public Double getPzmj() {
        return pzmj;
    }

    public void setPzmj(Double pzmj) {
        this.pzmj = pzmj;
    }

    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public Double getJzdj() {
        return jzdj;
    }

    public void setJzdj(Double jzdj) {
        this.jzdj = jzdj;
    }

    public Double getJzdj2() {
        return jzdj2;
    }

    public void setJzdj2(Double jzdj2) {
        this.jzdj2 = jzdj2;
    }

    public Double getJzdj3() {
        return jzdj3;
    }

    public void setJzdj3(Double jzdj3) {
        this.jzdj3 = jzdj3;
    }

    public Double getZdzmj() {
        return zdzmj;
    }

    public void setZdzmj(Double zdzmj) {
        this.zdzmj = zdzmj;
    }

    public Double getJzzmj() {
        return jzzmj;
    }

    public void setJzzmj(Double jzzmj) {
        this.jzzmj = jzzmj;
    }
}
